<p align="center">

<p align="center">
   <img width="50%" height="40%" src="" alt="Logo">
  </p>

  <h1 align="center">jqllm</h1>
  <p align="center">
  <strong>JQ on LLM Steroids</strong>
    <br> <br />
    <a href="#status"><strong> Status</strong></a> |
    <a href="#why"><strong> Why</strong></a> |
    <a href="#how"><strong> How </strong></a> |
    <a href="#installation"><strong> Installation </strong></a> |
    <a href="#usage"><strong> Usage </strong></a> |
    <a href="#roadmap"><strong> Roadmap </strong></a> 

   </p>
<p align="center">

<p align="center">
<a href="https://pypi.org/project/jqllm/"><img src="https://img.shields.io/pypi/v/jqllm?label=PyPI"></a>
<a href="https://github.com/Florents-Tselai/jqllm/actions/workflows/test.yml?branch=mainline"><img src="https://github.com/Florents-Tselai/jqllm/actions/workflows/test.yml/badge.svg"></a>
<a href="https://codecov.io/gh/Florents-Tselai/jqllm"><img src="https://codecov.io/gh/Florents-Tselai/jqllm/branch/main/graph/badge.svg"></a>  
<a href="https://opensource.org/licenses/MIT license"><img src="https://img.shields.io/badge/MIT license.0-blue.svg"></a>
<a href="https://github.com/Florents-Tselai/jqllm/releases"><img src="https://img.shields.io/github/v/release/Florents-Tselai/jqllm?include_prereleases&label=changelog"></a>

## Status

## Why

## How


## Installation

## Usage

```bash
pip install jqllm
```

### Development

```bash
pip install -e '.[test]'
pytest
```

